unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, SMLChecks, ExtCtrls, ComCtrls;

type
  TfrmMain = class(TForm)
    lblInformation: TLabel;
    btnOk: TButton;
    btnCancel: TButton;
    SMLCheckProcessor: TSMLCheckProcessor;
    lblName: TLabel;
    edName: TEdit;
    lblKind: TLabel;
    cbKind: TComboBox;
    chkConfirmation: TCheckBox;
    gbDiscount: TGroupBox;
    lblValidFrom: TLabel;
    dtpFrom: TDateTimePicker;
    lblPercent: TLabel;
    edPercent: TEdit;
    lblCountry: TLabel;
    cbCountry: TComboBox;
    imgChecks: TImageList;
    lblImport: TLabel;
    edImport: TEdit;
    bvlButtons: TBevel;
    procedure FormCreate(Sender: TObject);
    procedure btnOkClick(Sender: TObject);
    procedure btnCancelClick(Sender: TObject);
  private
    { Private declarations }
    procedure CustomChecking(Sender: TObject);
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}
{$R winxp.res}

procedure TfrmMain.FormCreate(Sender: TObject);
var
  editCheck: TSMLCheckProviderEdit;
  cbCheck: TSMLCheckProviderCombobox;
  chkCheck: TSMLCheckProviderCheckbox;
  numCheck: TSMLCheckProviderNumericEdit;

  custCheck: TSMLCheckProvider;
begin
  {add the check for name's editbox}
  editCheck := TSMLCheckProviderEdit.Create(SMLCheckProcessor.CheckProviders);
  editCheck.CheckControl := edName;
  editCheck.HintText := 'Enter the Name. Value can not be empty';

  {add the check for combobox}
  cbCheck := TSMLCheckProviderCombobox.Create(SMLCheckProcessor.CheckProviders);
  cbCheck.CheckControl := cbKind;
  cbCheck.HintText := 'Select the Kind from dropdown list';

  {check for percent range}
  numCheck := TSMLCheckProviderNumericEdit.Create(SMLCheckProcessor.CheckProviders);
  numCheck.CheckControl := edPercent;
  numCheck.MinValue := 0;
  numCheck.MaxValue := 50;
  imgChecks.GetBitmap(0, numCheck.Picture.Bitmap); {load custom picture}
  numCheck.HintText := 'Valid range for percent is from 0 to 50';

  {user must accept/confirm changes}
  chkCheck := TSMLCheckProviderCheckbox.Create(SMLCheckProcessor.CheckProviders);
  chkCheck.CheckControl := chkConfirmation;
  chkCheck.HintText := 'You must accept changes before save';

  {add custom check (via event) for date and record kind}
  custCheck := TSMLCheckProvider.Create(SMLCheckProcessor.CheckProviders);
  custCheck.OnCheck := CustomChecking;
end;

procedure TfrmMain.CustomChecking(Sender: TObject);
var
  check: TSMLCheckProvider;
begin
  check := TSMLCheckProvider(Sender);
  Check.Picture.Bitmap := nil;

  {1. user can't define the date for discount less than current date (only for Vendor records)
   2. if Country=USA then date must be greater than 01/01/2003
   3. file for import must exist}
  if (cbKind.Text = 'Vendor') and (dtpFrom.Date < Date()) then
  begin
    check.CheckControl := dtpFrom;
    check.HintText := 'Date must be greater than current date';
    imgChecks.GetBitmap(1, Check.Picture.Bitmap); {load custom picture}
    check.CheckStatus := csFailed
  end
  else
  if (cbCountry.Text = 'USA') and (dtpFrom.Date < EncodeDate(2003, 01, 01)) then
  begin
    check.CheckControl := dtpFrom;
    imgChecks.GetBitmap(1, Check.Picture.Bitmap); {load custom picture}
    check.HintText := 'Date must be greater than January 01, 2003';
    check.CheckStatus := csFailed
  end
  else
  if (edImport.Text <> '') and not FileExists(edImport.Text) then
  begin
    check.CheckControl := edImport;
    check.HintText := 'File is not exist';
    imgChecks.GetBitmap(2, Check.Picture.Bitmap); {load custom picture}
    check.CheckStatus := csFailed
  end
end;

procedure TfrmMain.btnOkClick(Sender: TObject);
begin
  if (btnOk.ModalResult = mrOk) then exit;

  {check all defined providers}
  if SMLCheckProcessor.Execute then
  begin
    {close the dialog form}
    btnOk.ModalResult := mrOk;
    btnOk.Click
  end
end;

procedure TfrmMain.btnCancelClick(Sender: TObject);
begin
  Close
end;

end.
